#include "SPI.h"
#include "Adafruit_GFX.h"
#include "Adafruit_ILI9341.h"
#include "Wire.h"      // this is needed even tho we aren't using it
#include "Adafruit_STMPE610.h"
#include "TouchScreen.h"
#include <Fonts/FreeSansBold18pt7b.h>
#include <Fonts/FreeSans12pt7b.h>

// These are the four touchscreen analog pins
#define YP A2  // must be an analog pin, use "An" notation!
#define XM A3  // must be an analog pin, use "An" notation!
#define YM 5   // can be a digital pin
#define XP 4   // can be a digital pin

// This is calibration data for the raw touch data to the screen coordinates
#define TS_MINX 160
#define TS_MINY 100
#define TS_MAXX 880
#define TS_MAXY 900

#define MINPRESSURE 1
#define MAXPRESSURE 1000

// The display uses hardware SPI, plus #9 & #10
#define TFT_CS 10
#define TFT_DC 9
Adafruit_ILI9341 tft = Adafruit_ILI9341(TFT_CS, TFT_DC);

// For better pressure precision, we need to know the resistance
// between X+ and X- Use any multimeter to read it
// For the one we're using, its 300 ohms across the X plate
TouchScreen ts = TouchScreen(XP, YP, XM, YM, 266);


int screenOneOn;
int screenTwoOn;
int aboutMeOn;
int experienceOn;
int skillsOn;
int contactInfoOn;
int systemInfoOn;
int percentPower;
float maxV = 4.15;
float minV = 3.7;
float a;
float b;
float voltage;


void setup() {
  Serial.begin(9600);
  tft.begin();
  tft.fillScreen(ILI9341_BLACK);
  tft.setRotation(0);
  screenOne();
  tapText();
//  testGrid();
}


void loop() {
  TSPoint p = ts.getPoint(); //Read touch screen point
  if (p.z > MINPRESSURE && p.z < MAXPRESSURE) { //If pressure is within valid range
    p.x = map(p.x, TS_MINX, TS_MAXX, 0, tft.width());  //Scale from ~0->1000 to tft.width using the calibration #'s  
    p.y = map(p.y, TS_MINY, TS_MAXY, 0, tft.height());

    if (screenOneOn == 1){
      screenTwo();
      p.z = 0;
    }
    
    if (screenTwoOn == 1 && p.z > 0){
      if (p.y > 0 && p.y < 64){
      aboutMe();
      p.z = 0;
      }
      if (p.y > 64 && p.y < 128) {
      experience();
      p.z = 0;
      }
      if (p.y > 128 && p.y < 192){
      skills();
      p.z = 0;
      }
      if (p.y > 192 && p.y < 256){
      contactInfo();
      p.z = 0;
      }
      if (p.y > 256 && p.y < 320){
      systemInfo();
      p.z = 0;
      }            
    }
    if (aboutMeOn == 1 && p.z > 0){
      screenTwo();
      p.z = 0;
    }
    if (experienceOn == 1 && p.z > 0){
      screenTwo();
      p.z = 0;
    }
    if (skillsOn == 1 && p.z > 0){
      screenTwo();
      p.z = 0;
    }
    if (contactInfoOn == 1 && p.z > 0){
      screenTwo();
      p.z = 0;
    }    
    if (systemInfoOn == 1 && p.z > 0){
      screenTwo();
      p.z = 0;
    }    
  }
  if (systemInfoOn == 1){
    
  }
}

unsigned long tapText(){
  tft.setFont();
  tft.setTextColor(ILI9341_WHITE);
  tft.setTextSize(2);
  tft.setTextWrap(0);
  tft.setCursor(50,300);
  tft.print("<Tap Screen>");
}

unsigned long screenOne(){ 
  screenOneOn = 1;
  screenTwoOn = 0;
  aboutMeOn = 0;
  experienceOn = 0;
  skillsOn = 0;
  contactInfoOn = 0;
  systemInfoOn = 0;
  tft.setFont(&FreeSans12pt7b);
  tft.setTextColor(ILI9341_GREEN);
  tft.setTextSize(2);
  tft.setCursor(60,125);
  tft.print("Jared");
  tft.setCursor(0,180);
  tft.print("Humphreys");
  tft.setFont();
  tft.setTextSize(3);
  tft.setTextColor(ILI9341_WHITE);
  tft.setCursor(50,220);
  tft.print("Engineer");
}

unsigned long screenTwo() { 
  screenOneOn = 0;
  screenTwoOn = 1;
  aboutMeOn = 0;
  experienceOn = 0;
  skillsOn = 0;
  contactInfoOn = 0;
  systemInfoOn = 0;
  tft.fillScreen(ILI9341_BLACK);
  tft.drawRect(0,0,240,320,ILI9341_WHITE);
  tft.drawFastHLine(0,64,240,ILI9341_WHITE);
  tft.drawFastHLine(0,128,240,ILI9341_WHITE);
  tft.drawFastHLine(0,192,240,ILI9341_WHITE);
  tft.drawFastHLine(0,256,240,ILI9341_WHITE);     
  tft.setFont(&FreeSansBold18pt7b);
  tft.setTextSize(1);
  tft.setTextColor(ILI9341_WHITE);
  tft.setCursor(40,45);
  tft.print("About Me");
  tft.setCursor(26,108);
  tft.print("Experience");
  tft.setCursor(75,172);
  tft.print("Skills");
  tft.setCursor(17,235);
  tft.print("Contact Info");
  tft.setCursor(20,300);
  tft.print("System Info");
}

unsigned long aboutMe(){
  screenOneOn = 0;
  screenTwoOn = 0;
  aboutMeOn = 1;
  experienceOn = 0;
  skillsOn = 0;
  contactInfoOn = 0;
  systemInfoOn = 0;
  tft.fillScreen(ILI9341_BLACK);
  tft.setFont(&FreeSans12pt7b);
  tft.setTextSize(1);
  tft.setCursor(0,20);
  tft.setTextWrap(1);
  tft.print("Engineer specializing   in inventing, designing, fabricating, and              implementing systems that involve principles of Mechanical Engineering, Electrical Engineering, and programming. I like to design cool        stuff then get my          hands dirty making it.");  
}

unsigned long experience(){
  screenOneOn = 0;
  screenTwoOn = 0;
  aboutMeOn = 0;
  experienceOn = 1;
  skillsOn = 0;
  contactInfoOn = 0;
  systemInfoOn = 0;
  tft.fillScreen(ILI9341_BLACK);

  tft.setFont();
  tft.setTextSize(2);
  tft.fillTriangle(195,0,175,20,215,20,ILI9341_RED);
  tft.setTextColor(ILI9341_RED);
  tft.setCursor(130,25);
  tft.print("Resume On");
  tft.setCursor(140,45);
  tft.print("SD Card");
  
  tft.setFont(&FreeSans12pt7b);
  tft.setTextSize(1);
  tft.setTextColor(ILI9341_WHITE);
  tft.setTextWrap(0);  
  tft.setCursor(0,85);
  tft.print("As of 2017-10-13:");  //Date last updated

  tft.setTextColor(ILI9341_CYAN); //Latest experience
  tft.setCursor(0,110);
  tft.print("Steico Industries");
  tft.setCursor(0,135);
  tft.print("Oceanside, CA");
  tft.setCursor(0,160);
  tft.print("April 2014-Aug. 2017");
  tft.setCursor(0,185);
  tft.print("Process Improvements");
  tft.setCursor(0,210);
  tft.print("Engineer");

  tft.setTextColor(ILI9341_DARKCYAN);
  tft.setCursor(0,243);
  tft.print("B.S. Mechanical");
  tft.setCursor(0,268);
  tft.print("Engineering, 2012");
  tft.setCursor(0,293);
  tft.print("University of Colorado");
  tft.setCursor(0,318);
  tft.print("Boulder");
  
}

unsigned long skills(){
  screenOneOn = 0;
  screenTwoOn = 0;
  aboutMeOn = 0;
  experienceOn = 0;
  skillsOn = 1;
  contactInfoOn = 0;
  systemInfoOn = 0;  
  tft.fillScreen(ILI9341_BLACK);
  tft.setFont(&FreeSans12pt7b);
  tft.setTextSize(1);
  tft.setCursor(0,20);
  tft.setTextWrap(1);
  tft.print("Welding (Esp. TIG)");
  tft.setCursor(0,50);
  tft.print("Machining (Manual,     CNC)");
  tft.setCursor(0,110);
  tft.print("SolidWorks (Certified SolidWorks Associate)");
  tft.setCursor(0,170);
  tft.print("PCB Design and Manufacturing");
  tft.setCursor(0,230);
  tft.print("3D Printing (FDM and SLA)");
  tft.setCursor(0,290);
  tft.print("<Additional Experience on SD Card>");
}

unsigned long contactInfo(){
  screenOneOn = 0;
  screenTwoOn = 0;
  aboutMeOn = 0;
  experienceOn = 0;
  skillsOn = 0;
  contactInfoOn = 1;
  systemInfoOn = 0;  
  tft.fillScreen(ILI9341_BLACK);
  tft.setFont(&FreeSans12pt7b);
  tft.setTextSize(1);
  tft.setCursor(0,20);
  tft.setTextWrap(1);
  tft.print("Cell:");
  tft.setCursor(0,50);
  tft.print("858-449-6657");
  tft.setCursor(0,90);
  tft.print("Email:");
  tft.setCursor(0,120);
  tft.print("JaredHumphreys3141@Gmail.com");
  tft.setCursor(0,190);
  tft.print("LinkedIn Profile:");
  tft.setCursor(0,220);
  tft.print("https://www.linkedin.com/in/jared-humphreys-4b652564/");
}

unsigned long systemInfo(){
  screenOneOn = 0;
  screenTwoOn = 0;
  aboutMeOn = 0;
  experienceOn = 0;
  skillsOn = 0;
  contactInfoOn = 0;
  systemInfoOn = 1;
  a = 100.0/(maxV-minV);
  b = 100.0-a*maxV;
  voltage = analogRead(4);
  voltage = voltage/155.1;
  percentPower = a*voltage+b;
  tft.fillScreen(ILI9341_BLACK);
  tft.setFont();  
  tft.fillTriangle(55,0,35,20,75,20,ILI9341_BLUE);
  tft.setTextColor(ILI9341_BLUE);
  tft.setTextSize(2);
  tft.setTextWrap(0);
  tft.setCursor(10,25);
  tft.print("Charging");
  tft.setCursor(10,45);
  tft.print("  Port");  
  tft.fillTriangle(195,0,175,20,215,20,ILI9341_RED);
  tft.setTextColor(ILI9341_RED);
  tft.setCursor(130,25);
  tft.print("Resume On");
  tft.setCursor(142,45);
  tft.print("SD Card");
  if(percentPower >= 40){
    tft.setTextColor(ILI9341_GREEN);
  }
  if(percentPower >= 15 && percentPower < 40){
    tft.setTextColor(ILI9341_YELLOW);
  }
  if(percentPower < 15){
    tft.setTextColor(ILI9341_RED);
  }
  tft.setCursor(0,68);
  tft.print("Batt: ");
  tft.print(voltage);
  tft.print("v   ");
  tft.print(percentPower);
  tft.print("%");
  tft.setTextColor(ILI9341_WHITE);  
  tft.setTextWrap(1);
  tft.setCursor(0,90);
  tft.print("Subassemblies (blue boards) and Arduino code libraries by   Adafruit Industries");
  tft.setCursor(0,160);
  tft.print("Carrier board (purple) manufactured by  OSH Park");
  tft.setCursor(0,215);
  tft.print("System concept and  design, carrier     board design in     EAGLE, Arduino code,and assembly by me");  
  tft.setCursor(0,305);
  tft.print("Card # 010"); //Card number
}

